package mod_perl_guide;
1;
__END__

=head1 NAME

mod_perl_guide - mod_perl Guide

=head1 SYNOPSIS

Use your favorite Netscape Browser to read the guide after installing
the package.

=head1 DESCRIPTION

This is a HTML version of the mod_perl guide. You can also see the
online version at http://perl.apache.org/guide .

mod_perl project's home page: http://perl.apache.org

=head1 INSTALLATION

The guide is gets installed just like any other Perl module:

  perl Makefile.PL
  make install

=head1 CORRECTIONS

Corrections and suggestions are welcome. If you submit patches, please
do that against the POD source files in I<src> directory. Thank you!

=head1 AUTHOR

Stas Bekman <stas@stason.org>

=head1 SEE ALSO

perl(1), mod_perl(1).

=cut
